@@ -26,14 +26,37 @@ static char sccsid[] = "@(#)ruserpass.c	5.5 (Berkeley) 6/27/88";
 #include <errno.h>
 #include <netdb.h>
 
-static void renv(const char *host, char **aname, char **apass);
-static char * renvlook(const char *host);
-static struct utmp *getutmp(char *sttyname);
-static	FILE *cfile;
-static void rnetrc(const char *host, char **aname, char **apass);
-static void mkpwclear(char *spasswd, char mch, char *sencpasswd);
-static int token();
+extern char *__libc_secure_getenv(const char *);
 
+static FILE *cfile;
+
+static int token( void );
+static void rnetrc(const char *, char **, char ** );
+static char *renvlook( const char * );
+static void renv( const char *, char **, char ** );
+void ruserpass( const char *, char **, char ** );
+static void mkpwclear( char *, char, char * );
+static char *mkenvkey( char );
+static void sreverse( register char *, register char * );
+static struct utmp *getutmp(char * );
+static void blkencrypt(char *, int );
+static void nbssetkey( char * );
+static void enblknot( char *, char * );
+static char *deblkclr( char * );
+static void enblkclr( char *, char * );
+static char *nbs8decrypt( char *, char * );
+static void mkpwclear( char *, char, char * );
+static char *mkenvkey( char );
+static void sreverse( register char *, register char * );
+static struct utmp *getutmp( char * );
+static void blkencrypt( char *, int );
+static void nbssetkey( char * );
+static void enblknot( char *, char * );
+static char *deblkclr( char * );
+static void enblkclr( char *, char * );
+static char *nbs8decrypt( char *, char * );
+static char *nbsdecrypt( char *, char *, char * );
+  
 #if NLS
 #include "nl_types.h"
 #endif
@@ -50,7 +73,7 @@ ruserpass(const char *host, char **aname, char **apass)
 #endif
 	strncpy(name, host, sizeof(name) - 1);
 
-	if (hp = gethostbyname (name))
+	if ((hp = gethostbyname (name)))
 		strncpy(name,hp->h_name, sizeof(name) - 1);
 	renv(name, aname, apass);
 	if (*aname == 0 || *apass == 0)
@@ -78,7 +101,7 @@ ruserpass(const char *host, char **aname, char **apass)
 			char *ptr;
 			*aname = namebuf;
 			namebuf [sizeof (namebuf) - 1] = '0';
-			if (ptr = index(namebuf, '\n'))
+			if ((ptr = index(namebuf, '\n')))
 				*ptr = 0;
 		}
 	}
@@ -162,19 +185,19 @@ static struct toktab {
 	char *tokstr;
 	int tval;
 } toktab[]= {
-	"default",	DEFAULT,
-	"login",	LOGIN,
-	"password",	PASSWD,
-	"notify",	NOTIFY,
-	"write",	WRITE,
-	"yes",		YES,
-	"y",		YES,
-	"no",		NO,
-	"n",		NO,
-	"command",	COMMAND,
-	"force",	FORCE,
-	"machine",	MACHINE,
-	0,		0
+	{ "default",	DEFAULT },
+	{ "login",	LOGIN },
+	{ "password",	PASSWD },
+	{ "notify",	NOTIFY },
+	{ "write",	WRITE },
+	{ "yes",		YES },
+	{ "y",		YES },
+	{ "no",		NO },
+	{ "n",		NO },
+	{ "command",	COMMAND },
+	{ "force",	FORCE },
+	{ "machine",	MACHINE },
+	{ 0,		0 }
 };
 
 static void
@@ -219,7 +242,7 @@ next:
 	case MACHINE:
 		if (token() != ID)
 			continue;
-		if(hp = gethostbyname (tokval))
+		if((hp = gethostbyname (tokval)))
 		{
 			if (strcmp(host, hp->h_name))
 				continue;
@@ -283,7 +306,7 @@ done:
 }
 
 static int
-token()
+token( void )
 {
 	char *cp;
 	int c;
@@ -332,19 +355,11 @@ token()
 /* rest is nbs.c stolen from berknet */
 
 #if 0
-static char *nbsencrypt(char *str, char *key, char *result);
-static char *nbs8encrypt(char *str, char *key);
-static char *deblknot(char *blk);
+static char *nbsencrypt(char *, char *, char * );
+static char *nbs8encrypt(char *, char * );
+static char *deblknot(char * );
 #endif
 
-static char *nbsdecrypt(char *cpt, char *key, char *result);
-static char *nbs8decrypt(char *crp, char *key);
-static void enblkclr(char *blk, char *str);
-static char *deblkclr(char *blk);
-static void enblknot(char *blk, char *crp);
-static void nbssetkey(char *key);
-static void blkencrypt(char *block, int edflag);
-
 static char	E[48];
 
 /*
@@ -367,9 +382,7 @@ static char	e[] = {
  * for buffer overflows.
  */
 static
-char *nbsencrypt(str,key,result)
-  char *str, *key;
-  char *result;
+char *nbsencrypt( char *str, char *key, char *result )
 {
 	static char buf[20],oldbuf[20];
 	register int j;
@@ -385,12 +398,10 @@ char *nbsencrypt(str,key,result)
 	return(result);
 }
 
-#endif
+#endif	/* if 0 */
 
 static
-char *nbsdecrypt(cpt,key,result)
-  char *cpt,*key;
-  char *result;
+char *nbsdecrypt( char *cpt, char *key, char *result )
 {
 	char *s;
 	char c,oldbuf[20];
@@ -410,8 +421,7 @@ char *nbsdecrypt(cpt,key,result)
 
 #if 0
 static
-char *nbs8encrypt(str,key)
-char *str, *key;
+char *nbs8encrypt( char *str, char *key )
 {
 	static char keyblk[100], blk[100];
 	register int i;
@@ -426,11 +436,10 @@ char *str, *key;
 	return(deblknot(blk));
 }
 
-#endif
-
+#endif	/* if 0 */
+  
 static
-char *nbs8decrypt(crp,key)
-char *crp, *key;
+char *nbs8decrypt( char *crp, char *key )
 {
 	static char keyblk[100], blk[100];
 	register int i;
@@ -446,8 +455,8 @@ char *crp, *key;
 }
 
 static void
-enblkclr(blk,str)	/* ignores top bit of chars in string str */
-char *blk,*str;
+enblkclr( char *blk, char *str )
+	/* ignores top bit of chars in string str */
 {
 	register int i,j;
 	char c;
@@ -460,8 +469,7 @@ char *blk,*str;
 }
 
 static
-char *deblkclr(blk)
-char *blk;
+char *deblkclr( char *blk )
 {
 	register int i,j;
 	char c;
@@ -479,9 +487,7 @@ char *blk;
 }
 
 static void
-enblknot(blk,crp)
-char *blk;
-char *crp;
+enblknot( char *blk, char *crp )
 {
 	register int i,j;
 	char c;
@@ -497,8 +503,7 @@ char *crp;
 
 #if 0
 static
-char *deblknot(blk)
-char *blk;
+char *deblknot( char *blk )
 {
 	register int i,j;
 	char c;
@@ -617,8 +622,7 @@ static	char	KS[16][48];
  */
 
 static void
-nbssetkey(key)
-char *key;
+nbssetkey( char *key )
 {
 	register i, j, k;
 	int t;
@@ -669,45 +673,45 @@ char *key;
  * index, unlike everything else.
  */
 static	char	S[8][64] = {
-	14, 4,13, 1, 2,15,11, 8, 3,10, 6,12, 5, 9, 0, 7,
+	{ 14, 4,13, 1, 2,15,11, 8, 3,10, 6,12, 5, 9, 0, 7,
 	 0,15, 7, 4,14, 2,13, 1,10, 6,12,11, 9, 5, 3, 8,
 	 4, 1,14, 8,13, 6, 2,11,15,12, 9, 7, 3,10, 5, 0,
-	15,12, 8, 2, 4, 9, 1, 7, 5,11, 3,14,10, 0, 6,13,
+	15,12, 8, 2, 4, 9, 1, 7, 5,11, 3,14,10, 0, 6,13 },
 
-	15, 1, 8,14, 6,11, 3, 4, 9, 7, 2,13,12, 0, 5,10,
+	{ 15, 1, 8,14, 6,11, 3, 4, 9, 7, 2,13,12, 0, 5,10,
 	 3,13, 4, 7,15, 2, 8,14,12, 0, 1,10, 6, 9,11, 5,
 	 0,14, 7,11,10, 4,13, 1, 5, 8,12, 6, 9, 3, 2,15,
-	13, 8,10, 1, 3,15, 4, 2,11, 6, 7,12, 0, 5,14, 9,
+	13, 8,10, 1, 3,15, 4, 2,11, 6, 7,12, 0, 5,14, 9 },
 
-	10, 0, 9,14, 6, 3,15, 5, 1,13,12, 7,11, 4, 2, 8,
+	{ 10, 0, 9,14, 6, 3,15, 5, 1,13,12, 7,11, 4, 2, 8,
 	13, 7, 0, 9, 3, 4, 6,10, 2, 8, 5,14,12,11,15, 1,
 	13, 6, 4, 9, 8,15, 3, 0,11, 1, 2,12, 5,10,14, 7,
-	 1,10,13, 0, 6, 9, 8, 7, 4,15,14, 3,11, 5, 2,12,
+	 1,10,13, 0, 6, 9, 8, 7, 4,15,14, 3,11, 5, 2,12 },
 
-	 7,13,14, 3, 0, 6, 9,10, 1, 2, 8, 5,11,12, 4,15,
+	{ 7,13,14, 3, 0, 6, 9,10, 1, 2, 8, 5,11,12, 4,15,
 	13, 8,11, 5, 6,15, 0, 3, 4, 7, 2,12, 1,10,14, 9,
 	10, 6, 9, 0,12,11, 7,13,15, 1, 3,14, 5, 2, 8, 4,
-	 3,15, 0, 6,10, 1,13, 8, 9, 4, 5,11,12, 7, 2,14,
+	 3,15, 0, 6,10, 1,13, 8, 9, 4, 5,11,12, 7, 2,14 },
 
-	 2,12, 4, 1, 7,10,11, 6, 8, 5, 3,15,13, 0,14, 9,
+	{ 2,12, 4, 1, 7,10,11, 6, 8, 5, 3,15,13, 0,14, 9,
 	14,11, 2,12, 4, 7,13, 1, 5, 0,15,10, 3, 9, 8, 6,
 	 4, 2, 1,11,10,13, 7, 8,15, 9,12, 5, 6, 3, 0,14,
-	11, 8,12, 7, 1,14, 2,13, 6,15, 0, 9,10, 4, 5, 3,
+	11, 8,12, 7, 1,14, 2,13, 6,15, 0, 9,10, 4, 5, 3 },
 
-	12, 1,10,15, 9, 2, 6, 8, 0,13, 3, 4,14, 7, 5,11,
+	{12, 1,10,15, 9, 2, 6, 8, 0,13, 3, 4,14, 7, 5,11,
 	10,15, 4, 2, 7,12, 9, 5, 6, 1,13,14, 0,11, 3, 8,
 	 9,14,15, 5, 2, 8,12, 3, 7, 0, 4,10, 1,13,11, 6,
-	 4, 3, 2,12, 9, 5,15,10,11,14, 1, 7, 6, 0, 8,13,
+	 4, 3, 2,12, 9, 5,15,10,11,14, 1, 7, 6, 0, 8,13 },
 
-	 4,11, 2,14,15, 0, 8,13, 3,12, 9, 7, 5,10, 6, 1,
+	{ 4,11, 2,14,15, 0, 8,13, 3,12, 9, 7, 5,10, 6, 1,
 	13, 0,11, 7, 4, 9, 1,10,14, 3, 5,12, 2,15, 8, 6,
 	 1, 4,11,13,12, 3, 7,14,10,15, 6, 8, 0, 5, 9, 2,
-	 6,11,13, 8, 1, 4,10, 7, 9, 5, 0,15,14, 2, 3,12,
+	 6,11,13, 8, 1, 4,10, 7, 9, 5, 0,15,14, 2, 3,12 },
 
-	13, 2, 8, 4, 6,15,11, 1,10, 9, 3,14, 5, 0,12, 7,
+	{13, 2, 8, 4, 6,15,11, 1,10, 9, 3,14, 5, 0,12, 7,
 	 1,15,13, 8,10, 3, 7, 4,12, 5, 6,11, 0,14, 9, 2,
 	 7,11, 4, 1, 9,12,14, 2, 0, 6,10,13,15, 3, 5, 8,
-	 2, 1,14, 7, 4,10, 8,13,15,12, 9, 0, 3, 5, 6,11,
+	 2, 1,14, 7, 4,10, 8,13,15,12, 9, 0, 3, 5, 6,11 },
 };
 
 /*
@@ -856,8 +860,7 @@ struct utmp *getutmp(char *sttyname)
 }
 
 static void
-sreverse(sto, sfrom)
-	register char *sto, *sfrom;
+sreverse( register char *sto, register char *sfrom )
 {
 	register int i;
 
@@ -904,8 +907,7 @@ char *mkenvkey(char mch)
 
 #if 0
 static void
-mkpwunclear(spasswd,mch,sencpasswd)
-	char *spasswd, mch, *sencpasswd;
+mkpwunclear( char *spasswd, char mch, char *sencpasswd )
 {
 	register char *skey;
 
@@ -924,8 +926,7 @@ mkpwunclear(spasswd,mch,sencpasswd)
 #endif
 
 static void
-mkpwclear(sencpasswd,mch,spasswd)
-	char *spasswd, mch, *sencpasswd;
+mkpwclear( char *spasswd, char mch, char *sencpasswd )
 {
 	register char *skey;
 
