@@ -6,10 +6,12 @@
 #include "libioP.h"
 #include "stdio.h"
 
+void setfileno( _IO_FILE *, int );
+
+void setfileno(_IO_FILE* fp, int fd) _IO_attr_weak;
+
 void
-setfileno(fp, fd)
-     _IO_FILE* fp;
-     int fd;
+setfileno( _IO_FILE *fp, int fd )
 {
   CHECK_FILE(fp, );
 #ifdef _LIBPTHREAD
@@ -24,6 +26,10 @@ setfileno(fp, fd)
 
 #ifndef _LIBPTHREAD
 #ifdef __ELF__
+#ifdef __GNUC__
+void setfileno( _IO_FILE *, int ) __attribute__ ((weak));
+#else
 #pragma weak setfileno
-#endif
-#endif
+#endif   /* __GNUC__ */
+#endif   /* __ELF__ */
+#endif   /* _LIBPTHREAD */
