@@ -13,9 +13,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.  */
 
 #include <ansidecl.h>
-#include <fp.h>
 #include <errno.h>
-#include "mathl.h"
+#include <math.h>
 
 long double
 DEFUN(acoshl, (x), long double x)
